hsimport-0.10.0: Extend the import list of a Haskell source file

Safe HaskellSafe
LanguageHaskell2010

HsImport.SymbolImport

Synopsis

Documentation

data SymbolImport Source #

What of the symbol should be imported.

Constructors

Symbol Name

only the symbol should be imported

AllOfSymbol Name

all constructors or methods of the symbol should be imported: Symbol(..)

SomeOfSymbol Name [String]

some constructors or methods of the symbol should be imported: Symbol(X, Y)

Instances
Show SymbolImport Source # 
Instance details

Defined in HsImport.SymbolImport