| Safe Haskell | Safe |
|---|---|
| Language | Haskell2010 |
HsImport.SymbolImport
Synopsis
- data SymbolImport
- = Symbol Name
- | AllOfSymbol Name
- | SomeOfSymbol Name [String]
Documentation
data SymbolImport Source #
What of the symbol should be imported.
Constructors
| Symbol Name | only the symbol should be imported |
| AllOfSymbol Name | all constructors or methods of the symbol should be imported: Symbol(..) |
| SomeOfSymbol Name [String] | some constructors or methods of the symbol should be imported: Symbol(X, Y) |
Instances
| Show SymbolImport Source # | |
Defined in HsImport.SymbolImport Methods showsPrec :: Int -> SymbolImport -> ShowS # show :: SymbolImport -> String # showList :: [SymbolImport] -> ShowS # | |